<?php

/**
 * @file
 * Contains \Drupal\replicate\EventSubscriber\ReplicateGroupSubscriber.
 */

namespace Drupal\replicate_group\EventSubscriber;

use Drupal\replicate\Events\AfterSaveEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\replicate\Events\ReplicatorEvents;

/**
 * Class ReplicateGroupSubscriber.
 *
 * @package Drupal\replicate\EventSubscriber
 */
class ReplicateGroupSubscriber implements EventSubscriberInterface {

  /**
   * Relate the replicated node to the same group(s) on behalf of the user.
   *
   * @param \Drupal\replicate\Events\AfterSaveEvent $event
   *   The event we're working on.
   */
  public function relateToGroup(AfterSaveEvent $event) {
    $entity = $event->getEntity();
    if ($event->getEntity()->getEntityTypeId() == 'node') {
      $account = \Drupal::currentUser();
      $storage = \Drupal::entityTypeManager()->getStorage('group');
      $gids = $storage->getQuery()
        ->execute();
      foreach ($storage->loadMultiple($gids) as $group) {
        if ($group->getMember($account)) {
          $group->addContent($entity, 'group_node:' . $entity->bundle());
        }
      }
  }
}

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[ReplicatorEvents::AFTER_SAVE][] = 'relateToGroup';
    return $events;
  }

}
